@@ -105,6 +105,13 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         self.assertEqual(address.city, 'HELSINKI')
         self.assertEqual(address.country, '')
 
+    def test_payee_fax(self):
+        """
+        test_payee_bank_account_number
+        """
+        payee = self.wrapper.payee
+        self.assertEqual(payee.fax, '(09) 1232500')
+
     def test_payee_bank_swift_code(self):
         """
         test_payee_bank_swift_code
@@ -151,6 +158,22 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         payee = self.wrapper.payee
         self.assertEqual(payee.website, 'www.pullinmusiikki.fi')
 
+    def test_payee_invoice_recipient_einvoice_address(self):
+        """
+        test_payee_invoice_recipient_einvoice_address
+        """
+        invoice_recipient = self.wrapper.invoice_recipient
+        self.assertEqual(invoice_recipient.einvoice_address, \
+                         'FI2757800750155448')
+
+    def test_payee_invoice_recipient_intermediator_address(self):
+        """
+        test_payee_invoice_recipient_intermediator_address
+        """
+        invoice_recipient = self.wrapper.invoice_recipient
+        self.assertEqual(invoice_recipient.intermediator_address, \
+                         'OKOYFIHH')
+
     def test_payee_organisation_unit_number(self):
         """
         test_payee_contact_phone
@@ -205,6 +228,7 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         """
         payer = self.wrapper.payer
         self.assertEqual(payer.net_service_id, '')
+        self.assertEqual(payer.intermediator, None)
 
     def test_payer_business_id(self):
         """
@@ -415,6 +439,7 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         self.assertEqual(row.freetext,
             u'Tuote myydään varsien ja ohjeen kanssa.\n')
         self.assertEqual(row.date, datetime.date(2004, 12, 13))
+        self.assertEqual(row.account_dimension_text, None)
 
     def test_rows_1(self):
         """
@@ -435,6 +460,8 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         self.assertEqual(row.vat_amount_currency, 'EUR')
         self.assertEqual(row.vat_percent, Decimal('22'))
         self.assertEqual(row.unit_code, 'kpl')
+        self.assertEqual(row.account_dimension_text, None)
+
 
     def test_rows_2(self):
         """
@@ -455,6 +482,27 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         self.assertEqual(row.vat_amount_currency, None)
         self.assertEqual(row.vat_percent, None)
         self.assertEqual(row.unit_code, None)
+        self.assertEqual(row.account_dimension_text, None)
+
+    def test_rows_5(self):
+        """
+        test_rows_1
+
+        Demonstrates the available attibutes of a row.
+        """
+        row = self.wrapper.rows[5]
+        self.assertEqual(row.name, 'Mikseri')
+        self.assertEqual(row.article_identifier, '44213213')
+        self.assertEqual(row.quantity, 12)
+        self.assertEqual(row.unit_price, Decimal('192.62'))
+        self.assertEqual(row.total_untaxed, Decimal('2265.21'))
+        self.assertEqual(row.total_untaxed_currency, 'EUR')
+        self.assertEqual(row.vat_amount, Decimal('498.35'))
+        self.assertEqual(row.vat_amount_currency, 'EUR')
+        self.assertEqual(row.vat_percent, Decimal('22'))
+        self.assertEqual(row.unit_code, 'kpl')
+        self.assertEqual(row.account_dimension_text, '4500')
+
 
     def test_delivery_party_contact_email(self):
         """
@@ -621,6 +669,7 @@ class TestFinvoiceWrapperWithPankkiyhdistysFinvoice(FinvoiceTestCase):
         """
         payer = self.wrapper.payer
         self.assertEqual(payer.net_service_id, 'FI3329501800008512')
+        self.assertEqual(payer.intermediator, 'NDEAFIHH')
 
     def test_payee_net_service_id(self):
         """
@@ -628,3 +677,4 @@ class TestFinvoiceWrapperWithPankkiyhdistysFinvoice(FinvoiceTestCase):
         """
         payee = self.wrapper.payee
         self.assertEqual(payee.net_service_id, 'FI9859292720000267')
+        self.assertEqual(payee.intermediator, 'OKOYFIHH')
