@@ -209,7 +209,9 @@ class InvoiceRecipient(object):
     party_identifier = ''
     tax_code = ''
     address = None
-
+    einvoice_address = ''
+    intermediator_address = ''
+    
     def __init__(self, doc):
         self.address = InvoiceRecipientAddress()
 
@@ -235,6 +237,22 @@ class InvoiceRecipient(object):
             if len(tax_code) > 0:
                 self.tax_code = organisation_name[0].text
 
+        info_details = doc.SellerInformationDetailsSet
+        if len(info_details) > 0:
+            invoice_recipient_details = info_details[0].InvoiceRecipientDetailsSet
+            if len(invoice_recipient_details) > 0:
+
+                invoice_recipient_einvoice_address = \
+                    invoice_recipient_details[0].InvoiceRecipientAddressSet
+                if len(invoice_recipient_einvoice_address) > 0:
+                    self.einvoice_address = \
+                         invoice_recipient_einvoice_address[0].text
+
+                invoice_recipient_intermediator_address = \
+                    invoice_recipient_details[0].InvoiceRecipientIntermediatorAddressSet
+                if len(invoice_recipient_intermediator_address) > 0:
+                    self.intermediator_address = \
+                         invoice_recipient_intermediator_address[0].text
 
 class DeliveryParty(object):
     contact_email = ''
@@ -304,19 +322,22 @@ class Payee(object):
     contact_phone = ''
     iban_account_number = ''
     phone = ''
+    fax = ''
     website = ''
     organisation_unit_number = ''
     organisation_taxcode = ''
     bank_accounts = None
+    intermediator = None
 
     def __init__(self, doc, envelope=None):
         if envelope:
             self.net_service_id = envelope.seller_id
+            self.intermediator = envelope.seller_intermediator_id
 
         self.postal_address = SellerPostalAddress()
         self.delivery_address = DeliveryAddress()
         self.bank_accounts = []
-
+        
         epi = doc.EpiDetailsSet
         if len(epi) > 0:
             party_details = epi[0].EpiPartyDetailsSet
@@ -345,6 +366,10 @@ class Payee(object):
             if len(website) > 0:
                 self.website = website[0].text
 
+            fax = info_details[0].SellerFaxNumberSet
+            if len(fax) > 0:
+                self.fax = fax[0].text
+
             for account in info_details[0].SellerAccountDetailsSet:
                 account_number = account.SellerAccountIDSet[0].text
                 swift_code = account.SellerBicSet[0].text
@@ -355,7 +380,7 @@ class Payee(object):
         if len(org_unit_number) > 0:
             self.organisation_unit_number = org_unit_number[0].text
             if not self.business_id \
-                and self.organisation_unit_number.startswith('0037') \
+                and str(self.organisation_unit_number).startswith('0037') \
                     and len(self.organisation_unit_number) > 11:
                         business_id = self.organisation_unit_number[4:12]
                         if BusinessID.is_valid(business_id):
@@ -396,7 +421,6 @@ class Payee(object):
                 self.contact_email = email[0].text
 
 
-
 class Payer(object):
 
     name = ''
@@ -414,6 +438,7 @@ class Payer(object):
     #website = ''
     organisation_unit_number = ''
     organisation_taxcode = ''
+    intermediator = None
 
     def __init__(self, doc=None, envelope=None):
         self.net_service_id = ''
@@ -421,6 +446,7 @@ class Payer(object):
 
         if envelope:
             self.net_service_id = envelope.buyer_id
+            self.intermediator = envelope.buyer_intermediator_id
 
         org_unit_number = doc.BuyerOrganisationUnitNumberSet
         if len(org_unit_number) > 0 and org_unit_number[0].text:
@@ -489,6 +515,7 @@ class Row(object):
     unit_code = None
     freetext = None
     article_identifier = None
+    account_dimension_text = None
 
     def __init__(self, row):
         self.name = row.ArticleNameSet.as_string()
@@ -559,6 +586,10 @@ class Row(object):
         if len(vat_percent) > 0:
             self.vat_percent = vat_percent[0].text
 
+        account_dimension_text = row.RowAccountDimensionTextSet
+        if len(account_dimension_text) > 0:
+            self.account_dimension_text = account_dimension_text[0].text
+
         date_id = row.RowIdentifierDateSet
         delivery_date = row.RowDeliveryDateSet
         if len(date_id) > 0:
